@@ -525,7 +525,7 @@ def find_cols(all_cols: list[str], stubs: list[str] = None) -> list[str]:
     
     result = []
     for stub in stubs:
-        result.extend([col for col in all_cols if stub in col])
+        result.extend([col for col in all_cols if stub.lower() in col.lower()])
     
     return result
 
@@ -598,3 +598,124 @@ def add_measures_to_pyg_config(json_path: str, nodes: list[tuple[str, str]] = [(
     # * Write the updated JSON back to the file
     with open(json_path, "w", encoding="utf-8") as file:
         json.dump(config, file, indent=2)
+
+
+
+def get_tum_details(z_tum_id: str, con: ddb.DuckDBPyConnection) -> None:
+    """
+    Prints the details of a specific tumor to the console.
+    Needs con to clinical cancer data
+    v2.3
+
+    Args:
+        z_tum_id (str): The ID of the tumor to retrieve details for.
+        con (dbr.DuckDB): A DuckDB connection object.
+
+    Returns:
+        None
+    """
+    print("pat")
+    (con.sql(f"""--sql
+        select
+                z_pat_id,
+                z_sex,
+                Geburtsdatum,
+                Diagnosedatum,
+                DatumVitalstatus,
+                Verstorben,
+                z_age,
+                z_ag05,
+        from Patient
+        join Tumor on Patient.oBDS_RKIPatientId = Tumor.z_pat_id
+        where z_tum_id = '{z_tum_id}'
+        order by z_tum_order
+        """)
+        .show()
+    )
+    print("tum1")
+    (con.sql(f"""--sql
+        select  z_kkr_label,
+                z_icd10,
+                z_tum_op_count,
+                z_tum_st_count,
+                z_tum_sy_count,
+                z_tum_fo_count,
+                z_first_treatment,
+                z_first_treatment_after_days,
+                z_tum_order,
+                z_last_tum_status,
+        from Tumor
+        where z_tum_id = '{z_tum_id}'
+        order by z_tum_order
+        """)
+        .show()
+    )
+
+    print("tum2")
+    (con.sql(f"""--sql
+        select
+                z_event_order,
+                z_events,
+                Anzahl_Tage_Diagnose_Tod,
+                z_period_diag_death_day,
+                DatumPSA,
+                z_period_diag_psa_day,
+                z_class_hpv,
+        from Tumor
+        where z_tum_id = '{z_tum_id}'
+        order by z_tum_order
+        """)
+        .show()
+    )
+
+    print("op")
+    (con.sql(f"""--sql
+        select * exclude (z_kkr)
+        from OP
+        where z_tum_id = '{z_tum_id}'
+        order by z_op_order
+        """)
+        .project("* exclude (z_tum_id)")
+        .show()
+    )
+    print("st")
+    (con.sql(f"""--sql
+        select * exclude (z_kkr)
+        from ST
+        where z_tum_id = '{z_tum_id}'
+        """)
+        .project("* exclude (z_tum_id)")
+        .show()
+    )
+
+    print("be")
+    (con.sql(f"""--sql
+        select * exclude (z_kkr)
+        from Bestrahlung
+        where z_tum_id = '{z_tum_id}'
+        order by z_bestr_order
+        """)
+        .project("* exclude (z_tum_id)")
+        .show()
+    )
+
+    print("syst")
+    (con.sql(f"""--sql
+        select * exclude (z_kkr)
+        from SYST
+        where z_tum_id = '{z_tum_id}'
+        order by z_syst_order
+        """)
+        .project("* exclude (z_tum_id)")
+        .show()
+    )
+
+    print("fo")
+    (con.sql(f"""--sql
+        select * exclude (z_kkr)
+        from Folgeereignis
+        where z_tum_id = '{z_tum_id}'
+        """)
+        .project("* exclude (z_tum_id)")
+        .show()
+    )
