@@ -1,7 +1,7 @@
 from pathlib import Path
 import warnings
 
-warnings.filterwarnings("ignore")
+from pandas_plots import tbl
 
 import os
 from typing import Optional, Literal
@@ -11,15 +11,18 @@ import seaborn as sb
 from matplotlib import pyplot as plt
 from plotly import express as px
 import plotly.graph_objects as go
+import plotly.io as pio
 from plotly.subplots import make_subplots
 import plotly  # needed for return types
+
 import re
 
 from .hlp import *
 from .tbl import print_summary
 
-### helper functions
+warnings.filterwarnings("ignore")
 
+### helper functions
 
 def _set_caption(caption: str) -> str:
     return f"#️⃣{'-'.join(caption.split())}, " if caption else ""
@@ -499,6 +502,11 @@ def plot_stacked_bars(
     fig.update_xaxes(showgrid=True, gridwidth=1)
     fig.update_yaxes(showgrid=True, gridwidth=1)
 
+    fig.update_layout(
+        width=width,
+        height=height,
+    )
+
     # * save to png if path is provided
     if png_path is not None:
         fig.write_image(Path(png_path).as_posix())
@@ -782,6 +790,11 @@ def plot_bars(
             textposition="outside",
             # error_y=dict(thickness=0)
         )
+    
+    _fig.update_layout(
+        width=width,
+        height=height,
+    )
 
     # * set axis title
     _fig.show(
@@ -813,6 +826,7 @@ def plot_histogram(
     caption: str = None,
     title: str = None,
     png_path: Path | str = None,
+    print_summary: bool = False,
 ) -> None:
     """
     A function to plot a histogram based on *numeric* columns in a DataFrame.
@@ -823,7 +837,7 @@ def plot_histogram(
     Parameters:
         df_ser (pd.DataFrame | pd.Series): The input containing the data to be plotted.
         histnorm (Literal["probability", "probability density", "density", "percent", None]): The normalization mode for the histogram. Default is None.
-        nbins (int): The number of bins in the histogram. Default is 0.
+        nbins (int): The number of bins in the histogram. Default is 0. If its set to -1, the number of bins will represent the integer span of the data.
         orientation (Literal["h", "v"]): The orientation of the histogram. Default is "v".
         precision (int): The precision for rounding the data. Default is 2.
         height (int): The height of the plot. Default is 500.
@@ -834,6 +848,7 @@ def plot_histogram(
         caption (str): The caption for the plot. Default is None.
         title (str): The title of the plot. Default is None.
         png_path (Path | str, optional): The path to save the image as a png file. Defaults to None.
+        print_summary (bool): Whether to print a summary table of the data. Default is False.
 
 
     Returns: None
@@ -855,6 +870,10 @@ def plot_histogram(
     # * rounding
     df = df.applymap(lambda x: round(x, precision))
 
+    # * nbins defaults to number of unique values
+    if nbins == -1:
+        nbins = int(df.max() - df.min())
+
     # ! plot
     _caption = _set_caption(caption)
     fig = px.histogram(
@@ -881,9 +900,14 @@ def plot_histogram(
         },
         showlegend=False if df.shape[1] == 1 else True,
     )
+    
+    fig.update_layout(
+        width=width,
+        height=height,
+    )    
 
     fig.show(
-        renderer,
+        renderer=renderer or os.getenv("RENDERER"),
         width=width,
         height=height,
     )
@@ -892,6 +916,9 @@ def plot_histogram(
     if png_path is not None:
         fig.write_image(Path(png_path).as_posix())
 
+    if print_summary:
+        tbl.print_summary(df)
+
     return
 
 
@@ -1142,6 +1169,11 @@ def plot_box(
             y=-0,
         )
 
+    fig.update_layout(
+        width=width,
+        height=height,
+    )
+
     fig.show(
         renderer=renderer or os.getenv("RENDERER"),
         width=width,
@@ -1517,6 +1549,12 @@ def plot_facet_stacked_bars(
     if relative:
         fig.update_yaxes(tickformat=".0%")
 
+    fig.update_layout(
+        width=subplot_size * subplots_per_row,
+        height=subplot_size
+        * (-(-len(aggregated_df["facet"].unique()) // subplots_per_row)),
+    )
+
     if png_path:
         png_path = Path(png_path)
         fig.write_image(str(png_path))
@@ -1859,9 +1897,90 @@ def plot_sankey(
         ]
     )
 
-    fig.update_layout(title_text=chart_title, font_size=font_size)
+
+    fig.update_layout(title_text=chart_title, font_size=font_size, width=width, height=height)
     fig.show(renderer=renderer or os.getenv("RENDERER"), width=width, height=height)
 
+
+def plot_pie(
+    data: pd.Series | pd.DataFrame,
+    caption: str = None,
+    width=800,
+    height=500,
+    renderer="notebook",
+    donut_size=0,
+):
+    """
+    Creates and displays a pie or donut chart using Plotly Express.
+
+    Args:
+        data (pd.Series or pd.DataFrame): The data to plot.
+            If a DataFrame, it must have only one column. The index will be
+            used for labels and the values for the pie slice sizes.
+        caption (str): The title for the plot.
+        height (int, optional): The height of the plot in pixels. Defaults to 800.
+        width (int, optional): The width of the plot in pixels. Defaults to 500.
+        renderer (str, optional): The Plotly renderer to use (e.g., 'notebook', 'png', 'svg').
+            Defaults to 'notebook'.
+        donut_size (float, optional): A value between 0 and 1 to create a donut chart.
+            A value of 0 results in a regular pie chart. Defaults to 0.
+    """
+    # Store the original renderer to restore it later
+    # original_renderer = pio.renderers.default
+    # ? override renderer
+    original_renderer = "notebook"
+
+    # * 1. Check for correct data type first
+    if not isinstance(data, (pd.Series, pd.DataFrame)):
+        print("Error: Data must be a pandas Series or DataFrame.")
+        return
+
+    # * 2. **CONVERT SERIES TO DATAFRAME**
+    if isinstance(data, pd.Series):
+        # * Get the name of the Series
+        label = data.name
+        # * Convert the Series to a DataFrame with a column named 'values'
+        # * The index will automatically become the DataFrame index
+        data = data.to_frame(name="values")
+    else:
+        # * Get the name of the first column
+        label = data.columns[0]
+
+    # * 3. Ensure the DataFrame has only one column
+    if len(data.columns) != 1:
+        print("Error: DataFrame must have exactly one column for this function.")
+        return
+
+    # * Set the temporary renderer for the plot
+    pio.renderers.default = renderer
+
+    # * Get the number of observations
+    n = len(data)
+
+    # * take 1st (only) column and use value counts to get distribution
+    data = data.iloc[:, 0].value_counts()
+
+    # * 4. Create the figure
+    fig = px.pie(
+        data,
+        values=data,
+        names=data.index,
+        title=f"{_set_caption(caption)}{label}, n = {n:_}",
+        height=height,
+        width=width,
+        hole=donut_size,
+        template="plotly_dark" if os.getenv("THEME") == "dark" else "plotly",
+    )
+
+    # * Display the plot
+    fig.show()
+
+    # finally:
+    # * 5. Restore the original renderer, ensuring it's always done
+    pio.renderers.default = original_renderer
+
+
+
 # * extend objects to enable chaining
 pd.DataFrame.plot_bars = plot_bars
 pd.DataFrame.plot_stacked_bars = plot_stacked_bars
@@ -1872,3 +1991,4 @@ pd.DataFrame.plot_quadrants = plot_quadrants
 pd.DataFrame.plot_histogram = plot_histogram
 pd.DataFrame.plot_joint = plot_joint
 pd.DataFrame.plot_sankey = plot_sankey
+pd.DataFrame.plot_pie = plot_pie
